package main

import (
	"embed"
	app2 "skapp/pkg/app"
	"skapp/pkg/app/dialog"
	"skapp/pkg/env"
	"skapp/pkg/sdk/system"
	systemUtils "skapp/pkg/system"
	"skapp/pkg/utils"

	"github.com/wailsapp/wails/v2"
	"github.com/wailsapp/wails/v2/pkg/options"
	"github.com/wailsapp/wails/v2/pkg/options/assetserver"
)

//go:embed all:frontend/dist
var assets embed.FS

func main() {
	defer func() {
		system.DestroyFileManager()
	}()
	// Create an instance of the app structure
	app := app2.NewApp()

	// Create application with options
	err := wails.Run(&options.App{
		Title:  "wails",
		Width:  1024,
		Height: 768,
		AssetServer: &assetserver.Options{
			Assets:  assets,
			Handler: app.Handler,
		},
		BackgroundColour: &options.RGBA{R: 255, G: 255, B: 255, A: 1},
		OnStartup:        app.Startup,
		OnBeforeClose:    app.BeforeClose,
		OnShutdown:       app.Shutdown,
		Bind: []interface{}{
			app,
			&env.Env{},
			&utils.Utils{},
			&systemUtils.InfoUtils{},
			dialog.New(app),
		},
		Debug: options.Debug{
			OpenInspectorOnStartup: true,
		},
	})

	if err != nil {
		println("Error:", err.Error())
	}
}
